package cz.jzitnik.game.crafting;

import cz.jzitnik.game.entities.items.InventoryItem;
import cz.jzitnik.game.entities.items.ItemBlockSupplier;

import java.util.*;

public class CraftingRecipeList {
    private static final List<CraftingRecipe> recipes = new ArrayList<>();

    static {
        // Oak planks
        recipes.add(new CraftingRecipe(new String[][]{
                {"oak_log", null, null},
                {null, null, null},
                {null, null, null}
        }, () -> new InventoryItem(4, ItemBlockSupplier.getItem("oak_planks"))));

        // Crafting table
        recipes.add(new CraftingRecipe(new String[][]{
                {"oak_planks", "oak_planks", null},
                {"oak_planks", "oak_planks", null},
                {null, null, null}
        }, () -> new InventoryItem(1, ItemBlockSupplier.getItem("crafting_table"))));

        // Stick
        recipes.add(new CraftingRecipe(new String[][]{
                {"oak_planks", null, null},
                {"oak_planks", null, null},
                {null, null, null}
        }, () -> new InventoryItem(4, ItemBlockSupplier.getItem("stick"))));

        // Wooden pickaxe
        recipes.add(new CraftingRecipe(new String[][]{
                {"oak_planks", "oak_planks", "oak_planks"},
                {null, "stick", null},
                {null, "stick", null}
        }, () -> new InventoryItem(1, ItemBlockSupplier.getItem("wooden_pickaxe"))));

        // Wooden axe
        recipes.add(new CraftingRecipe(new String[][]{
                {"oak_planks", "oak_planks", null},
                {"oak_planks", "stick", null},
                {null, "stick", null}
        }, () -> new InventoryItem(1, ItemBlockSupplier.getItem("wooden_axe"))));
        recipes.add(new CraftingRecipe(new String[][]{
                {null, "oak_planks", "oak_planks"},
                {null, "stick", "oak_planks"},
                {null, "stick", null}
        }, () -> new InventoryItem(1, ItemBlockSupplier.getItem("wooden_axe"))));

        // Stone pickaxe
        recipes.add(new CraftingRecipe(new String[][]{
                {"cobblestone", "cobblestone", "cobblestone"},
                {null, "stick", null},
                {null, "stick", null}
        }, () -> new InventoryItem(1, ItemBlockSupplier.getItem("wooden_axe"))));

        // Stone axe
        recipes.add(new CraftingRecipe(new String[][]{
                {"cobblestone", "cobblestone", null},
                {"cobblestone", "stick", null},
                {null, "stick", null}
        }, () -> new InventoryItem(1, ItemBlockSupplier.getItem("wooden_axe"))));
        recipes.add(new CraftingRecipe(new String[][]{
                {null, "cobblestone", "cobblestone"},
                {null, "stick", "cobblestone"},
                {null, "stick", null}
        }, () -> new InventoryItem(1, ItemBlockSupplier.getItem("wooden_axe"))));

        // Chest
        recipes.add(new CraftingRecipe(new String[][]{
                {"oak_planks", "oak_planks", "oak_planks"},
                {"oak_planks", null, "oak_planks"},
                {"oak_planks", "oak_planks", "oak_planks"}
        }, () -> new InventoryItem(1, ItemBlockSupplier.getItem("chest"))));

        // Wooden shovel
        recipes.add(new CraftingRecipe(new String[][]{
                {null, "oak_planks", null},
                {null, "stick", null},
                {null, "stick", null}
        }, () -> new InventoryItem(1, ItemBlockSupplier.getItem("wooden_shovel"))));

        // Stone shovel
        recipes.add(new CraftingRecipe(new String[][]{
                {null, "cobblestone", null},
                {null, "stick", null},
                {null, "stick", null}
        }, () -> new InventoryItem(1, ItemBlockSupplier.getItem("stone_shovel"))));

        recipes.add(new CraftingRecipe(new String[][]{
                {"cobblestone", "cobblestone", "cobblestone"},
                {"cobblestone", null, "cobblestone"},
                {"cobblestone", "cobblestone", "cobblestone"}
        }, () -> new InventoryItem(1, ItemBlockSupplier.getItem("furnace"))));

        recipes.add(new CraftingRecipe(new String[][]{
                {"oak_planks", "oak_planks", null},
                {"oak_planks", "oak_planks", null},
                {"oak_planks", "oak_planks", null}
        }, () -> new InventoryItem(1, ItemBlockSupplier.getItem("oak_door"))));
    }

    public static Optional<CraftingRecipe> getRecipe(String[] r) {
        for (CraftingRecipe recipe : recipes) {
            if (matchesByItemSet(recipe.getRecipe(), r)) {
                return Optional.of(recipe);
            }
        }
        return Optional.empty();
    }

    public static String[][] trimNullEdges(String[][] array) {
        int n = array.length;
        int minRow = n, maxRow = -1, minCol = n, maxCol = -1;

        // Find the bounding box of non-null values
        for (int i = 0; i < n; i++) {
            for (int j = 0; j < n; j++) {
                if (array[i][j] != null) {
                    minRow = Math.min(minRow, i);
                    maxRow = Math.max(maxRow, i);
                    minCol = Math.min(minCol, j);
                    maxCol = Math.max(maxCol, j);
                }
            }
        }

        // If all elements are null, return an empty array
        if (maxRow == -1) {
            return new String[0][0];
        }

        int newSizeRow = maxRow - minRow + 1;
        int newSizeCol = maxCol - minCol + 1;
        String[][] trimmedArray = new String[newSizeRow][newSizeCol];

        // Copy the relevant portion of the array
        for (int i = 0; i < newSizeRow; i++) {
            System.arraycopy(array[minRow + i], minCol, trimmedArray[i], 0, newSizeCol);
        }

        return trimmedArray;
    }

    public static boolean are2DArraysIdentical(String[][] array1, String[][] array2) {
        if (array1.length != array2.length) {
            return false;
        }

        for (int i = 0; i < array1.length; i++) {
            if (array1[i].length != array2[i].length) {
                return false;
            }

            for (int j = 0; j < array1[i].length; j++) {
                if (array1[i][j] == null && array2[i][j] != null) {
                    return false;
                }
                if (array1[i][j] != null && !array1[i][j].equals(array2[i][j])) {
                    return false;
                }
            }
        }

        return true;
    }

    private static boolean matchesByItemSet(String[][] recipe, String[] grid) {
        String[][] finalGrid = new String[3][3];

        if (grid.length == 4) {
            finalGrid[0][0] = grid[0];
            finalGrid[0][1] = grid[1];
            finalGrid[1][0] = grid[2];
            finalGrid[1][1] = grid[3];
        } else {
            finalGrid[0][0] = grid[0];
            finalGrid[0][1] = grid[1];
            finalGrid[0][2] = grid[2];
            finalGrid[1][0] = grid[3];
            finalGrid[1][1] = grid[4];
            finalGrid[1][2] = grid[5];
            finalGrid[2][0] = grid[6];
            finalGrid[2][1] = grid[7];
            finalGrid[2][2] = grid[8];
        }

        var croppedRecipe = trimNullEdges(recipe);
        var croppedGrid = trimNullEdges(finalGrid);

        return are2DArraysIdentical(croppedRecipe, croppedGrid);
    }
}
